@@ -9,7 +9,7 @@
 
 
 setMethod('aggregate', signature(x='Raster'), 
-function(x, fact=2, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
+function(x, fact, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
 
 
 	fact <- round(fact)
@@ -92,13 +92,13 @@ function(x, fact=2, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
 	}	
 
 	fun <- .makeTextFun(fun)
-	if (class(fun) == 'character') { 
+	if (class(fun)[1] == 'character') { 
 		op <- as.integer(match(fun, c('sum', 'mean', 'min', 'max')) - 1)
 	} else {
 		op <- NA
 	}
 
-	# note that it is yfact, xfact, zfact.
+	# note that it is yfact, xfact, zfact
 	dims <- as.integer(c(lastrow, lastcol, length(lyrs), yfact, xfact, zfact))
 	
 	if (is.na(op)) {
@@ -118,7 +118,7 @@ function(x, fact=2, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
 			if (!expand) {
 				nrow(xx) <- (nrow(x) %/% yfact) * yfact
 			}		
-			tr <- blockSize(xx, minrows=yfact)
+			tr <- blockSize(xx, n=nlayers(x)*xfact*yfact, minrows=yfact)
 			st <- round(tr$nrows[1] / yfact) * yfact
 			tr$n <- ceiling(lastrow / st)
 			tr$row <- c(1, cumsum(rep(st, tr$n-1))+1)
