@@ -90,6 +90,11 @@ function(x, by=NULL, sums=NULL, dissolve=TRUE, vars=NULL, ...) {
 	
 	if (isTRUE(is.null(by))) {
 		if (dissolve) {
+			gval <- rgeos::get_RGEOS_CheckValidity()
+			if (gval != 2) {
+				on.exit(rgeos::set_RGEOS_CheckValidity(gval))
+				rgeos::set_RGEOS_CheckValidity(2L)
+			}
 			if (rgeos::version_GEOS() < "3.3.0") {
 				x <- rgeos::gUnionCascaded(x)
 			} else {
@@ -101,7 +106,7 @@ function(x, by=NULL, sums=NULL, dissolve=TRUE, vars=NULL, ...) {
 				nsubobs <- length(x@polygons[[i]]@Polygons)
 				p <- c(p, lapply(1:nsubobs, function(j) x@polygons[[i]]@Polygons[[j]]))
 			}
-			x <- SpatialPolygons(list(Polygons(p, '1')), proj4string=proj4string(x))
+			x <- SpatialPolygons(list(Polygons(p, '1')), proj4string=x@proj4string)
 		}
 		#if (hd) {
 		#	x <- SpatialPolygonsDataFrame(x, data=data.frame(ID=1))
