@@ -67,13 +67,13 @@
 setMethod(erase, signature(x='SpatialPolygons', y='SpatialPolygons'),
     function(x, y, ...){ 
 	
-		requireNamespace("rgeos")
+		valgeos <- .checkGEOS(); on.exit(rgeos::set_RGEOS_CheckValidity(valgeos))
+
+		prj <- x@proj4string
+		if (is.na(prj)) prj <- y@proj4string
+		x@proj4string <- CRS(as.character(NA))
+		y@proj4string <- CRS(as.character(NA))
 
-		if (! identical(proj4string(x), proj4string(y)) ) {
-			warning('non identical CRS')
-			crs(y) <- proj4string(x)
-		}
-		
 		if (!.hasSlot(x, "data")) {
 			d <- data.frame(erase_dissolve_ID=1:length(x))
 			rownames(d) <- row.names(x)
@@ -109,10 +109,12 @@ setMethod(erase, signature(x='SpatialPolygons', y='SpatialPolygons'),
 		if (length(part2@polygons) > 1) {	
 			part2 <- aggregate(part2, colnames(part2@data))
 		}
+		part2@proj4string <- prj
+
 		if (dropframe) {
 			return( as(part2, 'SpatialPolygons') )
 		} else {
-			part2$erase_dissolve_ID <- NULL
+			part2@data$erase_dissolve_ID <- NULL
 			return( part2 )
 		}
 	}
@@ -121,11 +123,12 @@ setMethod(erase, signature(x='SpatialPolygons', y='SpatialPolygons'),
 setMethod(erase, signature(x='SpatialLines', y='SpatialPolygons'),
     function(x, y, ...){ 
 	
-		requireNamespace("rgeos")
-		if (! identical(proj4string(x), proj4string(y)) ) {
-			warning('non identical CRS')
-			crs(y) <- proj4string(x)
-		}
+		valgeos <- .checkGEOS(); on.exit(rgeos::set_RGEOS_CheckValidity(valgeos))
+		prj <- x@proj4string
+		if (is.na(prj)) prj <- y@proj4string
+		x@proj4string <- CRS(as.character(NA))
+		y@proj4string <- CRS(as.character(NA))
+
 		
 		if (!.hasSlot(x, 'data')) {
 			d <- data.frame(ID=1:length(x))
@@ -161,6 +164,8 @@ setMethod(erase, signature(x='SpatialLines', y='SpatialPolygons'),
 		if (length(part2@lines) > 1) {	
 			part2 <- aggregate(part2, colnames(part2@data))
 		}
+		
+		part2@proj4string <- prj
 		if (dropframe) {
 			return( as(part2, 'SpatialLines') )
 		} else {
