@@ -6,10 +6,11 @@
 
 
 setMethod('extract', signature(x='Raster', y='SpatialPolygons'), 
-function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cellnumbers=FALSE, small=TRUE, df=FALSE, layer, nl, factors=FALSE, sp=FALSE, ...){ 
+function(x, y, fun=NULL, na.rm=FALSE, exact=FALSE, weights=FALSE, normalizeWeights=TRUE, cellnumbers=FALSE, small=TRUE, df=FALSE, layer, nl, factors=FALSE, sp=FALSE, ...){ 
 
-	px <- projection(x, asText=FALSE)
-	comp <- compareCRS(px, projection(y), unknown=TRUE)
+	#px <-.getCRS(x, asText=FALSE)
+	px <-.getCRS(x)
+	comp <- compareCRS(px,.getCRS(y), unknown=TRUE)
 	if (!comp) {
 		.requireRgdal()
 		warning('Transforming SpatialPolygons to the CRS of the Raster')
@@ -25,8 +26,9 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 	
 	if (!is.null(fun)) {
 		cellnumbers <- FALSE
-	    if (weights) {
+	    if (weights || exact) {
 			if (!is.null(fun)) {
+				fun <- match.fun(fun)
 				test <- try(methods::slot(fun, 'generic') == 'mean', silent=TRUE)
 				if (!isTRUE(test)) {
 					warning('"fun" was changed to "mean"; other functions cannot be used when "weights=TRUE"' )
@@ -107,7 +109,7 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 		utils::flush.console()
 
 		.sendCall <- eval( parse( text="parallel:::sendCall") )
-		parallel::clusterExport(cl, c('rsbb', 'rr', 'weights', 'addres', 'cellnumbers', 'small'), envir=environment())
+		parallel::clusterExport(cl, c('rsbb', 'rr', 'weights', 'exact', 'addres', 'cellnumbers', 'small'), envir=environment())
 		
 		clFun <- function(i, pp) {
 			spbb <- bbox(pp)
@@ -126,24 +128,46 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 						weight <- xy[,3] #/ 100
 					}
 					xy <- xy[, -3, drop=FALSE]
+				} else if (exact) {
+					erc <- crop(x, rc)
+					xy <- exactextractr::exact_extract(erc, pp, include_cell=cellnumbers, progress=FALSE)[[1]]
 				} else {
 					rc <- .polygonsToRaster(pp, rc, silent=TRUE)
-					xy <- rasterToPoints(rc)[,-3,drop=FALSE]
+					r <- rasterToPoints(rc)[,-3,drop=FALSE]
 				}
 				
 				if (length(xy) > 0) { # catch very small polygons
-					r <- .xyValues(x, xy, layer=layer, nl=nl)
-					if (weights) {
-						if (cellnumbers) {
-							cell <- cellFromXY(x, xy)
-							r <- cbind(cell, r, weight)
-						} else {				
-							r <- cbind(r, weight)
+					if (exact) {
+						if (weights) {
+							if (normalizeWeights) {
+								xy$coverage_fraction <- xy$coverage_fraction / sum(xy$coverage_fraction)
+							}				
+							colnames(xy)[ncol(xy)] <- "weight"
+						} else {
+							xy$coverage_fraction  <- NULL
 						}
-					} else if (cellnumbers) {
-						cell <- cellFromXY(x, xy)
-						r <- cbind(cell, r)						
-					} 
+						if (cellnumbers) {
+							nms <- colnames(xy)
+							# not good if there is a layer called cell
+							nms <- c("cell", nms[nms != "cell"])
+							xy <- xy[,nms]
+						}
+						r <- as.matrix(xy)
+
+					} else {
+						r <- .xyValues(x, xy, layer=layer, nl=nl)
+						if (weights) {
+							if (cellnumbers) {
+								cell <- cellFromXY(x, xy)
+								r <- cbind(cell, r, weight)
+							} else {				
+								r <- cbind(r, weight)
+							}
+						} else if (cellnumbers) {
+							cell <- cellFromXY(x, xy)
+							r <- cbind(cell, r)						
+						}
+					}
 				} else {
 					if (small) {
 						ppp <- pp@polygons[[1]]@Polygons
@@ -153,7 +177,7 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 						if (length(xy) > 0) {
 							cell <- unique(unlist(lapply(xy, function(z) cellFromXY(x, z)), use.names = FALSE))
 							value <- .cellValues(x, cell, layer=layer, nl=nl)
-							if (weights) {
+							if (weights | exact) {
 								weight=rep(1/NROW(value), NROW(value))
 								if (cellnumbers) {
 									r <- cbind(cell, value, weight)
@@ -188,10 +212,10 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 
 			if (doFun) {
 				if (!is.null(d$value$value)) {
-					if (nl > 1 & !weights) {
+					if (nl > 1 & !(weights | exact)) {
 						res[[d$value$tag]] <- apply(d$value$value, 2, fun, na.rm=na.rm)							
 					} else { 
-						res[[d$value$tag]] <- fun(d$value$value)
+						res[[d$value$tag]] <- fun(d$value$value, na.rm=na.rm)
 					}
 				}
 			} else {
@@ -213,7 +237,10 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 				# do nothing; res[[i]] <- NULL
 			} else {
 				rc <- crop(rr, extent(pp)+addres)
-				if (weights) {
+				if (exact) {
+					erc <- crop(x, rc)
+					xy <- exactextractr::exact_extract(erc, pp, include_cell=cellnumbers, progress=FALSE)[[1]]	
+				} else if (weights) {
 					rc <- .polygonsToRaster(pp, rc, getCover=TRUE, silent=TRUE)
 					rc[rc==0] <- NA
 					xy <- rasterToPoints(rc)
@@ -229,7 +256,27 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 				}
 			
 				if (length(xy) > 0)  {  # catch holes or very small polygons
-					if (weights) {
+					if (exact) {
+						if (weights) {
+							if (normalizeWeights) {
+								xy$coverage_fraction <- xy$coverage_fraction / sum(xy$coverage_fraction)
+							}				
+							colnames(xy)[ncol(xy)] <- "weight"
+						} else {
+							xy$coverage_fraction  <- NULL
+						}
+						if (cellnumbers) {
+							nms <- colnames(xy)
+							# not good if there is a layer called cell
+							nms <- c("cell", nms[nms != "cell"])
+							xy <- xy[,nms]
+						}
+						if (ncol(xy) == 1) {
+							res[[i]] <- unlist(xy, use.names =FALSE)
+						} else {
+							res[[i]] <- as.matrix(xy)
+						}
+					} else if (weights) {
 						value <- .xyValues(x, xy, layer=layer, nl=nl)
 						if (cellnumbers) {
 							cell <- cellFromXY(x, xy)
@@ -252,7 +299,7 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 					if (length(xy) > 0) {
 						cell <- unique(unlist(lapply(xy, function(z) cellFromXY(x, z))), use.names = FALSE)
 						value <- .cellValues(x, cell, layer=layer, nl=nl)
-						if (weights) {
+						if (weights | exact) {
 							weight <- rep(1/NROW(value), NROW(value))
 							if (cellnumbers) {
 								res[[i]] <- cbind(cell, value, weight)
@@ -268,7 +315,7 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 				} 
 				if (doFun) {
 					if (!is.null(res[[i]])) {
-						if (nl > 1 & !weights) {
+						if (nl > 1 & !(weights | exact)) {
 							res[[i]] <- apply(res[[i]], 2, fun, na.rm=na.rm)							
 						} else {
 							res[[i]] <- fun(res[[i]], na.rm=na.rm)
@@ -320,7 +367,7 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, normalizeWeights=TRUE, cell
 		} else {
 			nms <- c('ID', names(x)[lyrs])
 		}
-		if (weights & is.null(fun)) {
+		if ((weights|exact) & is.null(fun)) {
 			nms <- c(nms, 'weight')
 		}
 		colnames(res) <- nms
