@@ -153,7 +153,12 @@ ccodes <- function() {
 		}
 	}	
 	if (file.exists(filename)) {
-		return(readRDS(filename))
+		x <- readRDS(filename)
+		# avoid pesky warnings
+		if (type != 'sf') {
+			crs(x) <- "+proj=longlat +datum=WGS84"
+		}
+		return(x)
 	} else {
 		return(NULL)
 	}
@@ -186,6 +191,7 @@ ccodes <- function() {
 		#thisenvir = new.env()
 		#data <- get(load(filename, thisenvir), thisenvir)
 		data <- readRDS(filename)
+		crs(data) <- "+proj=longlat +datum=WGS84"
 		return(data)
 	} 
 }
@@ -401,7 +407,7 @@ ccodes <- function() {
 	if (rowTile < 10) { rowTile <- paste('0', rowTile, sep='') }
 	if (colTile < 10) { colTile <- paste('0', colTile, sep='') }
 
-	baseurl <- "http://srtm.csi.cgiar.org/wp-content/uploads/files/srtm_5x5/TIFF/"
+	baseurl <- "https://srtm.csi.cgiar.org/wp-content/uploads/files/srtm_5x5/TIFF/"
 	
 	f <- paste0("srtm_", colTile, "_", rowTile, ".zip")
 
