@@ -67,6 +67,11 @@ setMethod("wkt", signature(obj="Raster"),
 
 
 .getCRS <- function(x) {
+
+	if (methods::extends(class(x), "CRS")) { 
+		return(x)
+	}
+
 	if (is.null(x)) {
 		x <- CRS()
 	} else if (methods::extends(class(x), "BasicRaster")) { 
@@ -82,9 +87,17 @@ setMethod("wkt", signature(obj="Raster"),
 	} else if (inherits(x, "SpatVector")) { 
 		crs <- crs(x)
 		x <- .makeCRS(x[1], x[2])
+	} else if (is.na(x)) {
+		x <- CRS()
 	} else if (is.character(x)) {
-		x <- CRS(x)
-
+		x <- trimws(x)
+		if (x == "") {
+			x <- CRS()
+		} else if (substr(x, 1, 1) == "+") {
+			x <- CRS(x)
+		} else {
+			x <- CRS(SRS_string = x)
+		}
 		#if (trimws(x) == "") {
 		#	x <- return(CRS())
 		#} else {
@@ -93,9 +106,12 @@ setMethod("wkt", signature(obj="Raster"),
 		#	x@projargs <- rgdal::showP4(wkt)
 		#	attr(x, "comment") <- wkt
 		#}
-	} else if (is.na(x)) {
+	} else if (is.numeric(x)) {
+		x <- paste0("EPSG:", round(x))
+		x <- CRS(SRS_string = x)	
+	} else {
 		x <- CRS()
-	}
+	} # else if "is CRS"
 	x
 }
 
